@@ -44,7 +44,6 @@ pub(crate) fn replace_qualified_name_with_use(
     // only offer replacement for non assoc items
     match ctx.sema.resolve_path(&path)? {
         hir::PathResolution::Def(def) if def.as_assoc_item(ctx.sema.db).is_none() => (),
-        hir::PathResolution::Macro(_) => (),
         _ => return None,
     }
     // then search for an import for the first path segment of what we want to replace
@@ -64,9 +63,11 @@ pub(crate) fn replace_qualified_name_with_use(
     );
     let path_to_qualifier = starts_with_name_ref
         .then(|| {
-            ctx.sema.scope(path.syntax()).module().and_then(|m| {
-                m.find_use_path_prefixed(ctx.sema.db, module, ctx.config.insert_use.prefix_kind)
-            })
+            ctx.sema.scope(path.syntax())?.module().find_use_path_prefixed(
+                ctx.sema.db,
+                module,
+                ctx.config.insert_use.prefix_kind,
+            )
         })
         .flatten();
 
